MongoKat
========

MongoKat is a minimalist MongoDB ORM/ODM, inspired by the "hands off" API of [MongoKit](https://github.com/namlook/mongokit).

See http://mongokat.readthedocs.org/ for documentation, code samples and API reference.

Tests
=====

[![Circle CI](https://circleci.com/gh/pricingassistant/mongokat.svg?style=svg)](https://circleci.com/gh/pricingassistant/mongokat)

You can just do `make test` to run the tests after setting up your environment (`make virtualenv` might help)

Contributing
============

We'll be happy to review any pull requests!

TODO
====

See the GitHub issues for a list of the features we'd like to add!

Docs
====

To edit the docs with livereload:

```
cd docs
make serve
```

Credits
=======

 - [MongoKit](https://github.com/namlook/mongokit), for the inspiration and part of the code
 - [PyMongo](https://github.com/mongodb/mongo-python-driver)
